/**
 * @agentuity/migrate — public API
 *
 * Programmatic access to the migration tool. For CLI usage, use the bin entry:
 *   npx @agentuity/migrate [project-dir]
 */
// v1 → v2 migration
export { migrate } from './migrate';
export { detect, } from './detect';
// v2 → v3 migration
export { migrateV3 } from './migrate-v3';
export { detectV3, } from './detect-v3';
//# sourceMappingURL=index.js.map