/**
 * Terminal report renderer.
 *
 * Formats the DetectionResult into a clear, readable console report.
 * No dependencies on @agentuity/cli's TUI — we use raw ANSI codes so that
 * this package can be run standalone via `npx @agentuity/migrate`.
 */
import type { DetectionResult } from './detect';
import type { V3DetectionResult } from './detect-v3';
export declare function printReport(detection: DetectionResult): void;
export declare function printStep(message: string): void;
export declare function printStepDone(detail?: string): void;
export declare function printStepSkipped(reason: string): void;
export declare function printStepFailed(reason: string): void;
export declare function printWarning(message: string): void;
export declare function printError(message: string): void;
export declare function printSuccess(message: string): void;
export declare function printManualSummary(detection: DetectionResult): void;
export declare function printChangeSummary(allChanges: {
    file: string;
    changes: string[];
}[]): void;
export declare function printV3Report(detection: V3DetectionResult): void;
export declare function printManualSummaryV3(detection: V3DetectionResult): void;
//# sourceMappingURL=report.d.ts.map